aboutsummaryrefslogtreecommitdiff
path: root/bbot/agent.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bbot/agent.hxx')
-rw-r--r--bbot/agent.hxx7
1 files changed, 4 insertions, 3 deletions
diff --git a/bbot/agent.hxx b/bbot/agent.hxx
index e5115ae..f009a64 100644
--- a/bbot/agent.hxx
+++ b/bbot/agent.hxx
@@ -18,9 +18,10 @@ namespace bbot
extern const string bs_prot; // Bootstrap protocol version.
- extern string tc_name; // Toolchain name.
- extern uint16_t tc_num; // Toolchain number.
- extern string tc_id; // Toolchain id.
+ extern string tc_name; // Toolchain name.
+ extern uint16_t tc_num; // Toolchain number.
+ extern standard_version tc_ver; // Toolchain version.
+ extern string tc_id; // Toolchain id.
extern string hname; // Our host name.
extern uid_t uid; // Our effective user id.